@@ -1,6 +1,6 @@
 package String::Perl::Warnings;
 {
-  $String::Perl::Warnings::VERSION = '1.08';
+  $String::Perl::Warnings::VERSION = '1.10';
 }
 
 #ABSTRACT: Determine if a string looks like a perl warning
@@ -951,7 +951,7 @@ q{\"\\B\{\"\ is\ deprecated\;\ use\ \"\\B\\\{\"\ or\ \"\\B\[\{\]\"\ instead\ in\
 q{\"\\b\{\"\ is\ deprecated\;\ use\ \"\\b\\\{\"\ instead},
 q{\"\\b\{\"\ is\ deprecated\;\ use\ \"\\b\\\{\"\ or\ \"\\b\[\{\]\"\ instead\ in\ regex\;\ marked\ by\ \<\-\-\ HERE\ in\ m\/.+?\/},
 q{\"\\c.+?\"\ is\ more\ clearly\ written\ simply\ as\ \".+?\"},
-q{\"\\c\{\"\ is\ deprecated\ and\ is\ more\ clearly\ written\ as\ \"\;\"},
+#q{\"\\c\{\"\ is\ deprecated\ and\ is\ more\ clearly\ written\ as\ \"\;\"}, # seriously this is nonsense
 q{\"my\ .+?\"\ used\ in\ sort\ comparison},
 q{\"my\ sub\"\ not\ yet\ implemented},
 q{\"my\"\ variable\ .+?\ can\'t\ be\ in\ a\ package},
@@ -1266,7 +1266,7 @@ String::Perl::Warnings - Determine if a string looks like a perl warning
 
 =head1 VERSION
 
-version 1.08
+version 1.10
 
 =head1 SYNOPSIS
 
